@@ -195,3 +195,22 @@ def prefix_key(data, prefix):
         data2[key] = value
     return data2
 
+
+def diff(object_instance1: dict, object_instance2: dict) -> typing.Tuple[list, list, list]:
+    """Find keys that changed. Returns: created_keys, updated_keys, deleted_keys
+    """
+    deleted_keys = []
+    updated_keys = []
+    created_keys = []
+
+    keys1 = set(object_instance1.keys())
+    keys2 = set(object_instance2.keys())
+
+    deleted_keys = list(keys1 - keys2)
+    created_keys = list(keys2 - keys1)
+    both_keys = keys1.intersection(keys2)
+    for key in both_keys:
+        if object_instance1[key] != object_instance2[key]:
+            updated_keys.append(key)
+    
+    return created_keys, updated_keys, deleted_keys
