@@ -7,10 +7,13 @@ import tempfile
 import shutil
 import yaml
 
-from .randomutils import uuid4
+from uuid import uuid4
 
 def mkdir(folder):
-    os.makedirs(folder, exist_ok=True)
+    """Create a folder if it's not exists.
+    """
+    if not os.path.exists(folder):
+        os.makedirs(folder, exist_ok=True)
     return os.path.exists(folder) and os.path.isdir(folder)
 
 def rm(filename):
@@ -45,10 +48,16 @@ def copy(src, dst, keep_src_folder_name=True, dst_is_a_folder=False):
             treecopy(src, dst, keep_src_folder_name)
 
 def pathjoin(path1, path2):
+    """Concat two paths.
+    """
     return os.path.join(path1, path2)
 
 
-def readfile(filename, binary=False, encoding="utf-8"):
+def readfile(filename, binary=False, encoding="utf-8", default=None):
+    """Read content from file. Return default value if the file not exists.
+    """
+    if not os.path.exists(filename):
+        return default
     if binary:
         with open(filename, "rb") as fobj:
             return fobj.read()
@@ -57,15 +66,22 @@ def readfile(filename, binary=False, encoding="utf-8"):
             return fobj.read()
 
 def write(filename, data, encoding="utf-8"):
+    """Write content data to file.
+    """
+    folder = os.path.dirname(filename)
+    if folder and not os.path.exists(folder):
+        os.makedirs(folder, exist_ok=True)
     if isinstance(data, bytes):
         with open(filename, "wb") as fobj:
             fobj.write(data)
     else:
-        with open(filename, "w", encoding="utf-8") as fobj:
+        with open(filename, "w", encoding=encoding) as fobj:
             fobj.write(data)
 
 
 def get_temp_workspace(prefix="", makedir=True):
+    """Create a temp folder and return it's path.
+    """
     folder_name = prefix + str(uuid4())
     path = os.path.abspath(os.path.join(tempfile.gettempdir(), folder_name))
     if makedir:
@@ -82,6 +98,8 @@ def rename(filepath, name):
     return dst
 
 def move(src, dst):
+    """Move a file or a folder to another place.
+    """
     os.rename(src, dst)
 
 def file_content_replace(filename, original, replacement, binary=False, encoding="utf-8", recursive=True, ignore_errors=True):
