@@ -1,7 +1,9 @@
 import os
 from logging.config import dictConfig
 
-def setup(config=None):
+from . import dictutils
+
+def get_simple_config(logfile=None, loglevel=None, logfmt=None, loggers=None, logging=None, **kwargs):
     """
         {
             "logfile": "LOG FILE PATH",
@@ -12,16 +14,50 @@ def setup(config=None):
             }
         }
     """
-    logfile = config.get("logfile", "app.log")
-    loglevel = config.get("loglevel", "INFO")
-    logfmt = config.get("logfmt", "default")
+    config = logging or {}
+    logfile = logfile or config.get("logfile", "app.log")
+    loglevel = loglevel or config.get("loglevel", "INFO")
+    logfmt = logfmt or config.get("logfmt", "default")
+    loggers = loggers or {}
 
     # make sure log folder exists...
-    logfolder = os.path.dirname(logfile)
+    logfolder = os.path.abspath(os.path.dirname(logfile))
     if not os.path.exists(logfolder):
         os.makedirs(logfolder, exist_ok=True)
 
-    config = config or {}
+    # fix windows log file rotating problem
+    default_file_handler_settings = {
+        "level": "DEBUG",
+        "class": "logging.handlers.TimedRotatingFileHandler",
+        "filename": logfile,
+        "when": "midnight",
+        "interval": 1,
+        "backupCount": 30,
+        "formatter": "default",
+    }
+    json_file_handler_settings = {
+        "level": "DEBUG",
+        "class": "logging.handlers.TimedRotatingFileHandler",
+        "filename": logfile,
+        "when": "midnight",
+        "interval": 1,
+        "backupCount": 30,
+        "formatter": "json",
+    }
+    if os.name == "nt":
+        default_file_handler_settings = {
+            "level": "DEBUG",
+            "class": "logging.FileHandler",
+            "filename": logfile,
+            "formatter": "default",
+        }
+        json_file_handler_settings = {
+            "level": "DEBUG",
+            "class": "logging.FileHandler",
+            "filename": logfile,
+            "formatter": "json",
+        }
+    
     logging_config = {
         "version": 1,
         "disable_existing_loggers": False,
@@ -30,6 +66,10 @@ def setup(config=None):
                 "format": "{asctime} {levelname} {pathname} {lineno} {module} {funcName} {process} {thread} {message}",
                 "style": "{"
             },
+            "message_only": {
+                "format": "{message}",
+                "style": "{",
+            },
             "json": {
                 "class": "jsonformatter.JsonFormatter",
                 "format": {
@@ -51,29 +91,13 @@ def setup(config=None):
                 "class": "logging.StreamHandler",
                 "formatter": "default",
             },
-            "default_file": {
-                "level": "DEBUG",
-                "class": "logging.handlers.TimedRotatingFileHandler",
-                "filename": logfile,
-                "when": "midnight",
-                "interval": 1,
-                "backupCount": 30,
-                "formatter": "default",
-            },
+            "default_file": default_file_handler_settings,
             "json_console": {
                 "level": "DEBUG",
                 "class": "logging.StreamHandler",
                 "formatter": "json",
             },
-            "json_file": {
-                "level": "DEBUG",
-                "class": "logging.handlers.TimedRotatingFileHandler",
-                "filename": logfile,
-                "when": "midnight",
-                "interval": 1,
-                "backupCount": 30,
-                "formatter": "json",
-            },
+            "json_file": json_file_handler_settings,
         },
         "loggers": {
         },
@@ -83,5 +107,10 @@ def setup(config=None):
             "propagate": True,
         }
     }
-    logging_config.update(config.get("logging", {}))
-    dictConfig(logging_config)
+    dictutils.deep_merge(logging_config, {"loggers": loggers})
+    dictutils.deep_merge(logging_config, config)
+    return logging_config
+
+def setup(*args, **kwargs):
+    config = get_simple_config(*args, **kwargs)
+    dictConfig(config)
